@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2024 (c)
  * 
  *    file: ukbd.h
  *    This file is part of the GnuDOS project.
@@ -22,23 +22,7 @@
 #define __U_KBD_H
 
 #include "kbd.h"
-/* mask values for bit pattern of first byte in multi-byte
-     UTF-8 sequences: 
-       192 - 110xxxxx - for U+0080 to U+07FF 
-       224 - 1110xxxx - for U+0800 to U+FFFF 
-       240 - 11110xxx - for U+010000 to U+1FFFFF */
-extern unsigned short mask[];// = {192, 224, 240};
-
-#ifndef __BOOL_DEFINED_
-#define __BOOL_DEFINED_
-typedef int bool;
-#endif
 
 char *ugetKey();
-char *ugetKeyUnderConsole();
-char *ugetKeyUnderX();
-
-//the Unicode character returned by ugetKey()
-char uc[5];
 
 #endif /* __U_KBD_H */
