@@ -29,11 +29,11 @@
 #include <sys/stat.h>
 
 int checkFileModified(char *open_file_name);
-void fileMenu_New(char *open_file_name);
-void fileMenu_Open(char *open_file_name);
-void fileMenu_Save(char* open_file_name);
-void fileMenu_SaveAs(char *open_file_name);
-void fileMenu_Print(char* open_file_name);
-void fileMenu_Exit(char* open_file_name);
+char *fileMenu_New(char *open_file_name);
+char *fileMenu_Open(char *open_file_name);
+char *fileMenu_Save(char* open_file_name);
+char *fileMenu_SaveAs(char *open_file_name);
+char *fileMenu_Print(char* open_file_name);
+char *fileMenu_Exit(char* open_file_name);
 
 #endif
