@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: help.h
  *    This file is part of mino.
@@ -23,9 +23,9 @@
 
 #include "defs.h"
 
-void showAboutBox();
-void showQuickReference();
-void showKeybindings();
-void showReadMe();
+void showAboutBox(void);
+void showQuickReference(void);
+void showKeybindings(void);
+void showReadMe(void);
 
 #endif
