@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: init.c
  *    This file is part of mino.
@@ -18,136 +18,158 @@
  *    You should have received a copy of the GNU General Public License
  *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
+
+#include "config.h"
+#define _GNU_SOURCE
+#define _XOPEN_SOURCE_EXTENDED
+#ifdef HAVE_NCURSESW_NCURSES_H
+# include <ncursesw/ncurses.h>
+#else
+# include <ncurses.h>
+#endif
 #include <pwd.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <getopt.h>
+#include <signal.h>
 #include <asm/types.h>
 #include "defs.h"
 #include "kbd.h"
 #include "edit.h"
 #include "options.h"
 #include "help.h"
+#include "dialogs.h"
 
 int     NEW_GNU_DOS_LEVEL;
-struct  passwd *pass;//will be used to find the home dir
 char   *STARTUP_FILE_NAME;
-char   *mino_ver = "2.0";
-char   *copyrightNotice = "Mino for GNU/Linux is developed by Mohammed Isam\n"
-                          "Copyright (C) Mohammed Isam 2014, 2015, 2016, 2017, 2018\n"
-                          "This is a GNU software, part of the GnuDOS package\n";
+char   *mino_ver = "2.1";
+char   *copyrightNotice =
+    "Mino for GNU/Linux is developed by Mohammed Isam\n"
+    "Copyright (C) Mohammed Isam 2014, 2015, 2016, 2017, 2018, 2024\n"
+    "This is a GNU software, part of the GnuDOS package\n";
+
+//whether to show README file on startup
 int  SHOW_README;
 
+wchar_t *DEFAULT_TITLE;
+int  open_file_at_startup;
 
-void outOfMemory()
+
+static inline void outOfMemory(void)
 {
     fprintf(stderr, "Fatal error: Insufficient memory\n");
     exit(1);
 }
 
-void exit_gracefully(int exit_code, char *open_file_name)
+static void catchSignals(void) 
 {
-    if(FILE_STATE == MODIFIED) 
+    if(signal(SIGINT, sighandler) == SIG_ERR) 
     {
-        int i = msgBox("File has been changed. Save changes?", YES|NO, INFO);
-      if(i == YES) 
-      {
-	if(NEW_FILE) 
-	{
-	  if(!openSaveFile(SAVE, YES, open_file_name)) 
-	  {
-	    msgBox("Failed to save file.", OK, ERROR);
-	  } else { FILE_STATE = SAVED; }
-	} 
-	else 
-	{
-	  if(!openSaveFile(SAVE, NO, open_file_name)) 
-	  {
-	    msgBox("Failed to save file.", OK, ERROR);
-	  } else { FILE_STATE = SAVED; }
-	}
-      } 
-      else if(i == CANCEL) 
-      { 
-	FILE_STATE = MODIFIED;
-      } else { FILE_STATE = IDLE; }
-    if(FILE_STATE == SAVED || FILE_STATE == IDLE)
-      goto good_to_go;
-  } else goto good_to_go;
-  refreshView();
-  return;
+        printf("Error interrupting SIGINT.\n");
+        exit(1);
+    }
 
-good_to_go:
-  fcloseall();
-  setScreenColors(WHITE, BGBLACK);
-  clearScreen(); 
-  restoreTerminal(); 
-  setScreenColors(WHITE, BGBLACK);
-  fprintf(stdout, "\x1b[24m");
-  fflush(stdout);
-  exit(exit_code); 
+    if(signal(SIGQUIT, sighandler) == SIG_ERR) 
+    {
+        printf("Error interrupting SIGQUIT.\n");
+        exit(1);
+    }
+
+    if(signal(SIGABRT, sighandler) == SIG_ERR) 
+    {
+        printf("Error interrupting SIGABRT.\n");
+        exit(1);
+    }
+
+    if(signal(SIGTERM, sighandler) == SIG_ERR) 
+    {
+        printf("Error interrupting SIGTERM.\n");
+        exit(1);
+    }
+
+    if(signal(SIGTSTP, sighandler) == SIG_ERR) 
+    {
+      //exit(1);
+    }
 }
 
 void parseLineArgs(int argc, char **argv) 
 {
+    struct  passwd *pass;
+    char *config_file_name;
+    FILE *config_file;
+
     GNU_DOS_LEVEL = 1;
     NEW_FILE = 1;
     FILE_STATE = NEW;
     open_file_at_startup = 0;
     AUTO_HIGHLIGHTING = 0;
     NEW_GNU_DOS_LEVEL = 0;
+
     ///////////////////////////////////////
     //parse command line arguments
     ///////////////////////////////////////
     int c;
     static struct option long_options[] =
     {
-	 {"reset-config", no_argument,            0,  'r'},
-	 {"help",         no_argument,            0,  'h'},
-	 {"level",  required_argument,            0,  'l'},
-	 {"version",      no_argument,            0,  'v'},
-	 {0, 0, 0, 0}
+        {"reset-config", no_argument,            0,  'r'},
+        {"help",         no_argument,            0,  'h'},
+        {"level",  required_argument,            0,  'l'},
+        {"version",      no_argument,            0,  'v'},
+        {0, 0, 0, 0}
     };
 
     while(1)
     {
-        int option_index=0;
+        int option_index = 0;
         c = getopt_long(argc, argv, "rhl:v", long_options, &option_index);
-        if(c==-1) break;	//end of options
+        if(c==-1) break;    //end of options
 
         switch(c)
         {
             case 0:
                 break;
-            case 'r':	//reset config file
+
+            case 'r':    //reset config file
                 if(!(pass = getpwuid(geteuid()))) 
                 {
-		    printf("Error: couldn't open home directory to write "
-			   "configuration file.\n");
-		    printf("Aborting.\n");
-		    exit(1);
+                    printf("Error: couldn't open home directory to write "
+                           "configuration file.\n");
+                    printf("Aborting.\n");
+                    exit(1);
                 }
-                config_file_name = (char *) malloc(strlen(pass->pw_dir)+12);
-                if(!config_file_name) { fprintf(stderr, "Insufficient memory\n"); exit(1); }
+
+                config_file_name = malloc(strlen(pass->pw_dir)+12);
+
+                if(!config_file_name)
+                {
+                    fprintf(stderr, "Insufficient memory\n");
+                    exit(1);
+                }
+
                 strcpy(config_file_name, pass->pw_dir);
                 strcat(config_file_name, "/");
                 strcat(config_file_name, ".mino.conf");
+
                 if(!(config_file = fopen(config_file_name, "w"))) 
                 {
-		    printf("Error: couldn't write to configuration file in "
-		           "your home directory.\n");
-		    printf("Aborting.\n");
-		    exit(1);
+                    printf("Error: couldn't write to configuration file in "
+                           "your home directory.\n");
+                    printf("Aborting.\n");
+                    exit(1);
                 }
+
                 printf("Resetting program configuration..\n");
                 _write_config_file(config_file, 1);
                 fclose(config_file);
                 printf("Finished writing default values to ~/.mino.conf\n");
+                free(config_file_name);
                 exit(0);
                 break;
-            case 'h':	//show program help
+
+            case 'h':    //show program help
                 printf("\nCommand line help for mino\n");
                 printf("%s\n", copyrightNotice);
                 printf("Usage: %s [filename][options]\n\n", argv[0]);
@@ -158,16 +180,19 @@ void parseLineArgs(int argc, char **argv)
                 printf("\t                  \tvalues to .mino.conf file\n");
                 printf("\t--help, -h        \tShow this command line help\n");
                 printf("\t--version, -v     \tShow program version\n");
-                printf("\t--levelX, -lX     \tSet the experience level, where X is 1-6\n");
+                printf("\t--levelX, -lX     \tSet the experience level, "
+                                             "where X is 1-6\n");
                 printf("For more information, see 'info mino' or the README"
                         " file in mino help menu\n");
                 exit(0);
                 break;
-            case 'v':	//show program version
+
+            case 'v':    //show program version
                 printf("%s\n", mino_ver);
                 exit(0);
                 break;
-            case 'l':	//set GNU_DOS level
+
+            case 'l':    //set GNU_DOS level
                 ;
                 int i = atoi(optarg);
                 if(i < 1 || i > 6)
@@ -179,45 +204,54 @@ void parseLineArgs(int argc, char **argv)
                 }
                 NEW_GNU_DOS_LEVEL = i;
                 break;
+
             case '?':
                 break;
+
             default:
                 abort();
-            }
+        }
     }
+
     ///////////////////////////////////////
     //parse the remaining arguments
     ///////////////////////////////////////
     STARTUP_FILE_NAME = NULL;
+
     if(optind < argc)
     {
-	  NEW_FILE = 0; FILE_STATE = OPENED;
-	  open_file_at_startup = 1;
-	  STARTUP_FILE_NAME = argv[optind];
+        NEW_FILE = 0;
+        FILE_STATE = OPENED;
+        open_file_at_startup = 1;
+        STARTUP_FILE_NAME = argv[optind];
     }
 }
 
-
-void init_error() 
+void init_error(void) 
 {
-      printf("Error: couldn't open home directory and read configuration file.\n");
-      printf("Will use built-in defaults. This means if you have set any\n");
-      printf("preferences (for example, display colors), they will be of\n");
-      printf("no effect.\n");
-      printf("You can reset your config file to program defaults by invoking:\n");
-      printf("mino --reset-config\n\nPress any key to continue..\n");
-      getchar();
-      //init_built_in_defaults();
+    printf("Error: couldn't open home directory and read configuration file.\n");
+    printf("Will use built-in defaults. This means if you have set any\n");
+    printf("preferences (for example, display colors), they will be of\n");
+    printf("no effect.\n");
+    printf("You can reset your config file to program defaults by invoking:\n");
+    printf("mino --reset-config\n\nPress any key to continue..\n");
+    getchar();
 }
 
-int __initNewDocument()
+int __initNewDocument(void)
 {
     if(totalLines)
     {
-	int i;
-        for(i = 0; i < totalLines; i++) freeLineStruct(lines[i]);
+        int i;
+        for(i = 0; i < totalLines; i++)
+        {
+            freeLineStruct(lines[i]);
+            lines[i] = NULL;
+        }
+
         totalLines = 0;
     }
+
     lines[0] = allocLineStructB(maxLen);
     if(!lines[0]) return 0;
     totalLines = 1;
@@ -225,27 +259,42 @@ int __initNewDocument()
     return 1;
 }
 
-int initNewDocument()
+int initNewDocument(void)
 {
     if(documentTitle) free(documentTitle);
-    documentTitle = (char *) malloc(strlen(DEFAULT_TITLE)+1);
+    documentTitle = wcsdup(DEFAULT_TITLE);
     if(!documentTitle) return 0;
-    strcpy(documentTitle, DEFAULT_TITLE);
     return __initNewDocument();
 }
 
-void resetLineCounters()
+void resetLineCounters(void)
 {
-    selectedLine       = 0;
-    selectedChar       = 0;
-    selectedCharCarry  = 0;
-    totalVisLines      = SCREEN_H-4;
-    firstVisLine       = 0;
+    selectedLine           = 0;
+    selectedChar           = 0;
+    selectedCharCarry      = 0;
+    userVisibleCurLine     = 0;
+    selectedCharIfPossible = 0;
+    totalVisLines          = SCREEN_H-4;
+    firstVisLine           = 0;
 }
 
 void __init()
 {
+    if(!initTerminal()) 
+    {
+        fprintf(stderr, "Fatal error: Failed to initialize the terminal.\r\n"
+                        "Aborting.\n");
+        exit(1);
+    }
+
     getScreenSize();
+
+    if(!SCREEN_H || !SCREEN_W)
+    {
+        fprintf(stderr, "Error: Failed to get terminal size\n");
+        exit(1);
+    }
+
     //1. Main Menu//
     menu[0] = "&File";
     menu[1] = "&Edit";
@@ -279,32 +328,14 @@ void __init()
     helpMenu[1] = "GNU Keybindings";
     helpMenu[2] = "Quick reference";
     helpMenu[3] = "About Mino..   ";
-    //initiate color arrays
-    FG_COLOR_ARRAY[0] = 30;
-    FG_COLOR_ARRAY[1] = 31;
-    FG_COLOR_ARRAY[2] = 32;
-    FG_COLOR_ARRAY[3] = 33;
-    FG_COLOR_ARRAY[4] = 34;
-    FG_COLOR_ARRAY[5] = 35;
-    FG_COLOR_ARRAY[6] = 36;
-    FG_COLOR_ARRAY[7] = 37;
-    BG_COLOR_ARRAY[0] = 40;
-    BG_COLOR_ARRAY[1] = 41;
-    BG_COLOR_ARRAY[2] = 42;
-    BG_COLOR_ARRAY[3] = 43;
-    BG_COLOR_ARRAY[4] = 44;
-    BG_COLOR_ARRAY[5] = 45;
-    BG_COLOR_ARRAY[6] = 46;
-    BG_COLOR_ARRAY[7] = 47;
     
-    //MAX_FILE_NAME_LEN = 100;
     AUTO_INDENT = 1;
-    autoIndentStr = (char *)malloc(512);
+    autoIndentStr = malloc(512 * sizeof(wchar_t));
     if(!autoIndentStr) outOfMemory();
     MAX_MSG_BOX_W      = SCREEN_W - 4;
     MAX_MSG_BOX_H      = SCREEN_H - 4;
     MAX_CHARS_PER_LINE = SCREEN_W - 2;
-    maxLen             = MAX_CHARS_PER_LINE*4;
+    maxLen             = MAX_CHARS_PER_LINE;
     CAPS               = 0;
     INSERT             = 0;
     SELECTING          = 0;
@@ -328,9 +359,47 @@ void __init()
 
     GNU_DOS_LEVEL = 1;
     WRAP_LINES    = 1;//TRUE -- restric line width to (screen width-2)
-    TAB_CHARS     = 8;	//define 8 spaces in a tab
+    TAB_CHARS     = 8;    //define 8 spaces in a tab
     SHOW_README   = 0;
 }
+
+static void post_config_file(char *open_file_name)
+{
+    if(AUTO_INDENT) optionsMenu[2] = strdup("Autoindent    *");
+    else optionsMenu[2] = strdup("Autoindent     ");
+ 
+    if(NEW_GNU_DOS_LEVEL) GNU_DOS_LEVEL = NEW_GNU_DOS_LEVEL;
+    if(GNU_DOS_LEVEL > 5 || GNU_DOS_LEVEL < 1) GNU_DOS_LEVEL = 1;
+ 
+    //set defaults for Dir view//
+    initDirView();
+    totalLines = 0;
+
+    if(NEW_FILE) 
+    {
+        if(!initNewDocument())
+        {
+            fprintf(stderr, "Fatal error: Insufficient memory\n");
+            exit(1);
+        }
+    }
+    else
+    {
+        char *slash = strrchr(open_file_name, '/');
+
+        if(slash) documentTitle = to_widechar(slash+1, NULL);
+        else      documentTitle = to_widechar(open_file_name, NULL);
+
+        if(!documentTitle)
+        {
+            fprintf(stderr, "Fatal error: Insufficient memory\n");
+            exit(1);
+        }
+    }
+ 
+    catchSignals();
+}
+
 /***************************************
  * init(): 
  * Procedure containing code that init-
@@ -338,30 +407,26 @@ void __init()
  * **************************************/
 void init(char *open_file_name)
 {
-    //int i;
-    DEFAULT_TITLE = __DEFAULT_TITLE;
-    //initiate color arrays
-    COLOR_STR[0] = "BLACK";
-    COLOR_STR[1] = "RED";
-    COLOR_STR[2] = "GREEN";
-    COLOR_STR[3] = "BROWN";
-    COLOR_STR[4] = "BLUE";
-    COLOR_STR[5] = "MAGENTA";
-    COLOR_STR[6] = "CYAN";
-    COLOR_STR[7] = "WHITE";
+    struct  passwd *pass;
+    char *config_file_name;
+    FILE *config_file;
+
+    DEFAULT_TITLE = to_widechar(__DEFAULT_TITLE, NULL);
     __init();
-    /////////////////////////////////////
   
     if(!(pass = getpwuid(geteuid()))) 
     {
         init_error();
-        goto post_config_file;
+        post_config_file(open_file_name);
+        return;
     }
-    config_file_name = (char *) malloc(strlen(pass->pw_dir)+11);
+
+    config_file_name = malloc(strlen(pass->pw_dir)+12);
     if(!config_file_name) outOfMemory();
     strcpy(config_file_name, pass->pw_dir);
     strcat(config_file_name, "/");
     strcat(config_file_name, ".mino.conf");
+
     if((config_file = fopen(config_file_name, "r"))) 
     {
         char buf[100];
@@ -369,16 +434,6 @@ void init(char *open_file_name)
         while(fgets(buf, sizeof(buf), config_file)) 
         {
             if(buf[0] == '#' || buf[0] == '\n') continue;
-            /*
-            if(strstr(buf, "MAXDIRS")) {
-                MAXDIRS = atoi((strchr(buf, "=")+2));
-            } else if (strstr(buf, "MAXFILES")) {
-                MAXFILES = atoi((strchr(buf, "=")+2));
-            } else if (strstr(buf, "MAXLINES")) {
-                MAX_LINES = atoi((strchr(buf, "=")+2));
-            } else if (strstr(buf, "MAX_CHARS_PER_LINE")) 
-                MAX_CHARS_PER_LINE = atoi((strchr(buf, '=')+2));
-            */
             if (strstr(buf, "GNU_DOS_LEVEL")) 
                 GNU_DOS_LEVEL = atoi((strchr(buf, '=')+2));
             else if (strstr(buf, "TAB_CHARS")) 
@@ -389,11 +444,17 @@ void init(char *open_file_name)
             else if (strstr(buf, "DEFAULT_TITLE")) 
             {
                 char *title = strchr(buf, '=')+2;
-                int titlelen = strlen(title);
-                DEFAULT_TITLE = (char *)malloc(titlelen+1);
-                if(!DEFAULT_TITLE) goto memerr;
-                strcpy(DEFAULT_TITLE, title);
-                DEFAULT_TITLE[titlelen-1] = '\0';
+                size_t titlelen = strlen(title);
+                DEFAULT_TITLE = to_widechar(title, NULL);
+
+                if(!DEFAULT_TITLE)
+                {
+                    fprintf(stderr, "Fatal error: Insufficient memory\n");
+                    exit(1);
+                }
+
+                if(DEFAULT_TITLE[titlelen-1] == L'\n')
+                    DEFAULT_TITLE[titlelen-1] = L'\0';
             }
             else if (strstr(buf, "WRAP_LINES")) 
             {
@@ -442,115 +503,75 @@ void init(char *open_file_name)
             else if (strstr(buf, "AUTO_INDENT")) 
                 AUTO_INDENT = atoi(strchr(buf, '=')+2);
         }
+
         fclose(config_file);
-        free(config_file_name); 
     }
     else write_config_file();
-    
-post_config_file:
-    if(AUTO_INDENT) optionsMenu[2] = strdup("Autoindent    *");
-    else optionsMenu[2] = strdup("Autoindent     ");
- 
-    if(NEW_GNU_DOS_LEVEL) GNU_DOS_LEVEL = NEW_GNU_DOS_LEVEL;
-    if(GNU_DOS_LEVEL > 5 || GNU_DOS_LEVEL < 1) GNU_DOS_LEVEL = 1;
- 
-    //set defaults for Dir view//
-    initDirView();
-    totalLines = 0;
 
-    if(NEW_FILE) 
-    {
-        if(!initNewDocument()) goto memerr;
-    }
-    else
-    {
-        int len;
-        char *slash = strrchr(open_file_name, '/');
-        if(slash) len = strlen(slash);
-        else      len = strlen(open_file_name);
-        documentTitle = (char *) malloc(len+1);
-        if(!documentTitle) goto memerr;
-        if(slash) strcpy(documentTitle, slash+1);
-        else      strcpy(documentTitle, open_file_name);
-    }
- 
-    if(!initTerminal()) 
-    {
-        fprintf(stderr, "Fatal error: Failed to initialize the terminal.\r\nAborting.\n");
-        exit(1);
-    }
-    catchSignals();
-    return;
- 
-memerr:
-    fprintf(stderr, "Fatal error: Insufficient memory\n");
-    exit(1);
+    free(config_file_name); 
+    post_config_file(open_file_name);
 }
 
-
-void showREADMEOnStartup() 
+void showREADMEOnStartup(void)
 {
-  int x = SCREEN_H/2-3;
-  int y = SCREEN_W/2-20;
-  int w = y+40;
-  int h = x+6;
+    int x = SCREEN_H/2-3;
+    int y = SCREEN_W/2-20;
+    int w = y+40;
+    int h = x+6;
   
-  setScreenColorsI(COLOR_WINDOW);
-  drawBox(x, y, h, w, " Welcome to mino ", YES, 0);
-  printf("\e[%d;%dH", x+1, y+2);
-  printf("Welcome to mino!");
-  printf("\e[%d;%dH", x+2, y+2);
-  printf("README file will be shown to help you");
-  printf("\e[%d;%dH", x+3, y+2);
-  printf("start using mino.");
-  setScreenColorsI(COLOR_HBUTTONS);
-  printf("\e[%d;%dH", x+5, y+2);
-  printf("  OK  ");
-  setScreenColorsI(COLOR_BUTTONS);
-  printf("\e[%d;%dH", x+5, y+12);
-  printf(" Don't show README again ");
-  printf("\e[%d;%dH", x+5, y+2);
-  fflush(stdout);
-  int sel = 0;
-  char *c = (char *)malloc(5);
-  while((c = getKey())) 
-  {
-    switch(c[0]) 
+    setScreenColorsI(COLOR_WINDOW);
+    drawBox(x, y, h, w, " Welcome to mino ", 1);
+    mvprintw(x, y+1, "Welcome to mino!");
+    mvprintw(x+1, y+1, "README file will be shown to help you");
+    mvprintw(x+2, y+1, "start using mino.");
+    setScreenColorsI(COLOR_HBUTTONS);
+    mvprintw(x+4, y+1, "  OK  ");
+    setScreenColorsI(COLOR_BUTTONS);
+    mvprintw(x+4, y+11, " Don't show README again ");
+    move(x+4, y+1);
+    refresh();
+
+    int sel = 0;
+    char *c;
+
+    while((c = ugetKey())) 
     {
-      case(RIGHT_KEY):
-      case(LEFT_KEY):
-      case(TAB_KEY):
-	if(sel == 0) 
-	{
-	  setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-	  printf("\e[%d;%dH", x+5, y+2);
-	  printf("  OK  ");
-	  setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
-	  printf("\e[%d;%dH", x+5, y+12);
-	  printf(" Don't show README again ");
-	  printf("\e[%d;%dH", x+5, y+12);
-	  sel = 1;
-	} 
-	else 
-	{
-	  setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
-	  printf("\e[%d;%dH", x+5, y+2);
-	  printf("  OK  ");
-	  setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
-	  printf("\e[%d;%dH", x+5, y+12);
-	  printf(" Don't show README again ");
-	  printf("\e[%d;%dH", x+5, y+2);
-	  sel = 0;
-	} break;
-      case(ENTER_KEY):
-      case(SPACE_KEY):
-	if(sel == 0) SHOW_README = 1;
-	else SHOW_README = 0;
-	showReadMe();
-	write_config_file();
-	refreshView();
-	return;
-    }//end switch
-    fflush(stdout);
-  }//end while
+        switch(c[0]) 
+        {
+            case(RIGHT_KEY):
+            case(LEFT_KEY):
+            case(TAB_KEY):
+                if(sel == 0) 
+                {
+                    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
+                    mvprintw(x+4, y+1, "  OK  ");
+                    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
+                    mvprintw(x+4, y+11, " Don't show README again ");
+                    move(x+4, y+11);
+                    sel = 1;
+                } 
+                else 
+                {
+                    setScreenColors(FG_COLOR[COLOR_HBUTTONS], BG_COLOR[COLOR_HBUTTONS]);
+                    mvprintw(x+4, y+1, "  OK  ");
+                    setScreenColors(FG_COLOR[COLOR_BUTTONS], BG_COLOR[COLOR_BUTTONS]);
+                    mvprintw(x+4, y+11, " Don't show README again ");
+                    move(x+4, y+1);
+                    sel = 0;
+                } break;
+
+            case(ENTER_KEY):
+            case(SPACE_KEY):
+                if(sel == 0) SHOW_README = 1;
+                else SHOW_README = 0;
+
+                showReadMe();
+                write_config_file();
+                refreshView();
+                return;
+        }//end switch
+
+        refresh();
+    }//end while
 }
+
