@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: menu.c
  *    This file is part of mino.
@@ -19,6 +19,14 @@
  *    along with mino. If not, see <http://www.gnu.org/licenses/>.
  */    
 
+#include "config.h"
+#define _GNU_SOURCE
+#define _XOPEN_SOURCE_EXTENDED
+#ifdef HAVE_NCURSESW_NCURSES_H
+# include <ncursesw/ncurses.h>
+#else
+# include <ncurses.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include "defs.h"
@@ -28,8 +36,17 @@
 #include "options.h"
 #include "file.h"
 #include "help.h"
+#include "dialogs.h"
 
-#define EOL	10
+// defined in main.c
+extern char *open_file_name;
+
+//Menu items//
+char *menu[4];
+char *fileMenu[6];
+char *editMenu[10];
+char *optionsMenu[4];
+char *helpMenu[4];
 
 struct menustruct
 {
@@ -37,7 +54,6 @@ struct menustruct
     char **menuItems;
     int  menuItemCount;
     void (**func)();
-    //void (*func2)(char *arg);
 };
 
 int mSelect;
@@ -45,15 +61,17 @@ int endme;
 int menuIndex;
 struct menustruct *curMenu;
 
-void (*fileFuncs[])() =
+char *(*fileFuncs[])() =
 {
-    fileMenu_New, fileMenu_Open, fileMenu_Save, fileMenu_SaveAs, fileMenu_Print, fileMenu_Exit
+    fileMenu_New, fileMenu_Open, fileMenu_Save, fileMenu_SaveAs, 
+    fileMenu_Print, fileMenu_Exit
 };
 
 void (*editFuncs[])() =
 {
-    editMenu_Cut, editMenu_Copy, editMenu_Paste, editMenu_SelectAll, editMenu_Undo, 
-    editMenu_Redo, editMenu_DeleteLine, editMenu_Find, editMenu_Replace, editMenu_ToggleSelectMode,
+    editMenu_Cut, editMenu_Copy, editMenu_Paste, editMenu_SelectAll, 
+    editMenu_Undo, editMenu_Redo, editMenu_DeleteLine, editMenu_Find, 
+    editMenu_Replace, editMenu_ToggleSelectMode,
 };
 
 void (*optionsFuncs[])() =
@@ -71,7 +89,7 @@ struct menustruct mainMenu[] =
 {
     /* File menu */
     {
-        { 2, 2, 9, 19 }, fileMenu, fTotal, fileFuncs,
+        { 2, 2, 9, 19 }, fileMenu, fTotal, NULL /* fileFuncs */,
     },
     /* Edit menu */
     {
@@ -87,63 +105,57 @@ struct menustruct mainMenu[] =
     },
 };
     
-void drawMenuBox(struct menustruct *curMenu)
+static void drawMenuBox(struct menustruct *curMenu)
 {
+    int i;
     int x1 = curMenu->box[0];
     int y1 = curMenu->box[1];
     int x2 = curMenu->box[2];
     int y2 = curMenu->box[3];
     char **menuItems = curMenu->menuItems;
     int menuItemCount = curMenu->menuItemCount;
+
     setScreenColorsI(COLOR_WINDOW);
-    drawBox(x1++, y1++, x2, y2, NULL, YES, 0);
+    drawBox(x1++, y1++, x2, y2, NULL, 1);
     setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
-    fprintf(stdout, "\e[%d;%dH%s", x1, y1, menuItems[0]);
+    mvprintw(x1-1, y1-1, "%s", menuItems[0]);
     setScreenColorsI(COLOR_WINDOW);
-    int i;
+
     for(i = 1; i < menuItemCount; i++) 
     {
-      fprintf(stdout, "\e[%d;%dH%s", i+3, y1, menuItems[i]);
+        mvprintw(i+2, y1-1, "%s", menuItems[i]);
     }
-    fprintf(stdout, "\e[%d;%dH", x1, y2-1);
-    fflush(stdout);
+
+    move(x1-1, y2-2);
+    refresh();
 }
 
-void clearSelection(int y, int menuIndex, char **menuItems)
+static void clearSelection(int y, int menuIndex, char **menuItems)
 {
     //clear last selection
     setScreenColorsI(COLOR_WINDOW);
-    fprintf(stdout, "\e[%d;%dH%s", menuIndex+3, y, menuItems[menuIndex]);
+    mvprintw(menuIndex+2, y-1, "%s", menuItems[menuIndex]);
 }
 
-void highlightSelection(int y1, int y2, int menuIndex, char **menuItems)
+static void highlightSelection(int y1, int y2, int menuIndex, char **menuItems)
 {
     setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
-    fprintf(stdout, "\e[%d;%dH%s", menuIndex+3, y1, menuItems[menuIndex]);
-    fprintf(stdout, "\e[%d;%dH", menuIndex+3, y2);
-    fflush(stdout);
+    mvprintw(menuIndex+2, y1-1, "%s", menuItems[menuIndex]);
+    move(menuIndex+2, y2-1);
+    refresh();
 }
 
-void doEsc()
-{
-    /*
-    setScreenColorsI(COLOR_WINDOW);
-    refreshView();
-    fflush(stdout);
-    */
-    endme = 1;
-}
-
-void doUpDown(int step)
+static void doUpDown(int step)
 {
     clearSelection(curMenu->box[1]+1, mSelect, curMenu->menuItems);
     mSelect += step;
     if(mSelect < 0) mSelect = curMenu->menuItemCount-1;
     else if(mSelect >= curMenu->menuItemCount) mSelect = 0;
-    highlightSelection(curMenu->box[1]+1, curMenu->box[3]-1, mSelect, curMenu->menuItems);
+    highlightSelection(curMenu->box[1]+1, curMenu->box[3]-1, mSelect, 
+                       curMenu->menuItems);
 }
 
-void doRightLeft(int step)
+static void doRightLeft(int step)
 {
     menuIndex += step;
     if(menuIndex < 0) menuIndex = totalMainMenus-1;
@@ -158,20 +170,23 @@ void doRightLeft(int step)
  * right or left arrows navigate to next menu on the left and the right 
  * respectively.
  ***********************************************************************/
-void showMenu(int index, char *open_file_name)
+void showMenu(int index)
 {
     char *ch;
     menuIndex = index;
     hideCursor();
     
 loop:
+
     mSelect   = 0;
     endme     = 0;
     curMenu   = &mainMenu[menuIndex];
     drawMenuBox(curMenu);
+
     while(!endme) 
     {
-        ch = getKey();
+        ch = ugetKey();
+
         switch(ch[0]) 
         {
             case('f'):                      // switch to File menu
@@ -182,7 +197,7 @@ loop:
                     refreshView();
                     goto loop;
                 }
-                if(CTRL)
+                else if(CTRL)
                 {
                     if(GNU_DOS_LEVEL > 1)
                     {
@@ -191,6 +206,7 @@ loop:
                     }
                 }
                 break;
+
             case('e'):                      // switch to Edit menu
                 if(ALT)
                 {
@@ -200,6 +216,7 @@ loop:
                     goto loop;
                 }
                 break;
+
             case('o'):                      // switch to Options menu
                 if(ALT)
                 {
@@ -209,6 +226,7 @@ loop:
                     goto loop;
                 }
                 break;
+
             case('h'):                      // switch to Help menu
                 if(ALT)
                 {
@@ -218,54 +236,78 @@ loop:
                     goto loop;
                 }
                 break;
+
             case('g'):
                 if(GNU_DOS_LEVEL < 3) break;
                 if(!CTRL) break;
-                doEsc();
+                endme = 1;
                 break;
+
             case(ESC_KEY):
                 if(GNU_DOS_LEVEL > 2) break;
-                doEsc();
+                endme = 1;
                 break;
+
             case('p'):
                 if(GNU_DOS_LEVEL < 2) break;
                 if(!CTRL) break;
                 doUpDown(-1);
                 break;
+
             case(UP_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doUpDown(-1);
                 break;
+
             case('n'):
                 if(GNU_DOS_LEVEL < 2) break;
                 if(!CTRL) break;
                 doUpDown(1);
                 break;
+
             case(DOWN_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doUpDown(1);
                 break;
+
             case(RIGHT_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doRightLeft(1);
                 goto loop;
                 break;
+
             case('b'):
                 if(GNU_DOS_LEVEL < 2) break;
                 if(!CTRL) break;
                 doRightLeft(-1);
                 goto loop;
                 break;
+
             case(LEFT_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doRightLeft(-1);
                 goto loop;
                 break;
+
             case(ENTER_KEY):
                 showCursor();
                 if(menuIndex == 0)      // File menu has special treatment
                 {
-                    curMenu->func[mSelect](open_file_name);
+                    char *newfile;
+
+                    if((newfile = fileFuncs[mSelect](open_file_name)) &&
+                        newfile != open_file_name)
+                    {
+                        if(open_file_name) free(open_file_name);
+                        open_file_name = newfile;
+                    }
+
+                    // new file
+                    if(mSelect == 0)
+                    {
+                        if(open_file_name) free(open_file_name);
+                        open_file_name = NULL;
+                    }
                 }
                 else
                 {
@@ -279,5 +321,6 @@ loop:
     setScreenColorsI(COLOR_WINDOW);
     refreshView();
     showCursor();
-    fflush(stdout);
+    refresh();
 }
+
