@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2018 (c)
+ *    Copyright 2018, 2024 (c)
  * 
  *    file: modules.h
  *    This file is part of mino.
@@ -29,12 +29,12 @@ struct modulestruct
     int extsCount;
     char **exts;
     int keywordCount;
-    char **keywords;
+    wchar_t **keywords;
     // for multi-line comments
-    char *mlCommentStart;
-    char *mlCommentEnd;
+    wchar_t *mlCommentStart;
+    wchar_t *mlCommentEnd;
     // for single-line comments
-    char *slCommentStart;
+    wchar_t *slCommentStart;
     // treat keywords as case-sensitive
     char caseSensitive;
 };
