@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2018 (c)
+ *    Copyright 2018, 2024 (c)
  * 
  *    file: dirstruct.c
  *    This file is part of Prime.
@@ -19,10 +19,13 @@
  *    along with Prime.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
-#define DIRSTRUCT    1
-
+#include <stdlib.h>
 #include "dirstruct.h"
 
+struct dirstruct *dirs[MAXENTRIES];
+struct dirstruct *files[MAXENTRIES];
+
+
 void freeDirStruct(struct dirstruct *dir)
 {
     if(!dir) return;
@@ -33,6 +36,7 @@ void freeDirStruct(struct dirstruct *dir)
 void freeDirStructs(int start, int end)
 {
     int j;
+
     for(j = start; j < end; j++)
     {
         freeDirStruct(dirs[j]);
@@ -43,6 +47,7 @@ void freeDirStructs(int start, int end)
 void freeFileStructs(int start, int end)
 {
     int j;
+
     for(j = start; j < end; j++)
     {
         freeDirStruct(files[j]);
@@ -50,14 +55,15 @@ void freeFileStructs(int start, int end)
     }
 }
 
-struct dirstruct *allocDirStruct()
+struct dirstruct *allocDirStruct(void)
 {
-    struct dirstruct *dir = (struct dirstruct *)malloc(sizeof(struct dirstruct));
+    struct dirstruct *dir = malloc(sizeof(struct dirstruct));
     if(!dir) return NULL;
     dir->name = NULL;
     dir->namelen = 0;
     dir->star = ' ';
     dir->type = 'd';
+    dir->iswcs = 0;
     return dir;
 }
 
@@ -65,18 +71,20 @@ struct dirstruct *allocDirStructB(int bytes)
 {
     struct dirstruct *dir = allocDirStruct();
     if(!dir) return NULL;
-    dir->name = (char *)malloc(bytes);
+    dir->name = malloc(bytes);
     if(!dir->name) return NULL;
     return dir;
 }
 
-struct dirstruct *allocFileStruct()
+struct dirstruct *allocFileStruct(void)
 {
-    struct dirstruct *file = (struct dirstruct *)malloc(sizeof(struct dirstruct));
+    struct dirstruct *file = malloc(sizeof(struct dirstruct));
     if(!file) return NULL;
     file->name = NULL;
+    file->namelen = 0;
     file->star = ' ';
     file->type = 'r';
+    file->iswcs = 0;
     return file;
 }
 
@@ -84,7 +92,8 @@ struct dirstruct *allocFileStructB(int bytes)
 {
     struct dirstruct *dir = allocFileStruct();
     if(!dir) return NULL;
-    dir->name = (char *)malloc(bytes);
+    dir->name = malloc(bytes);
     if(!dir->name) return NULL;
     return dir;
 }
+
