@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2018 (c)
+ *    Copyright 2018, 2024 (c)
  * 
  *    file: dirstruct.h
  *
@@ -25,26 +25,20 @@
 struct dirstruct
 {
     char *name;
-    int  namelen;
+    size_t namelen;
     char star;
     char type;
+    char iswcs;     //1=name is widechare, 0=name is "normal" C-string
 };
 
-
-#ifdef DIRSTRUCT
-#   define DIRSTRUCT_EXTERN
-#else
-#   define DIRSTRUCT_EXTERN   extern
-#endif
-
-DIRSTRUCT_EXTERN struct dirstruct *dirs[MAXENTRIES];
-DIRSTRUCT_EXTERN struct dirstruct *files[MAXENTRIES];
+extern struct dirstruct *dirs[MAXENTRIES];
+extern struct dirstruct *files[MAXENTRIES];
 
 void freeDirStruct(struct dirstruct *dir);
 void freeDirStructs(int start, int end);
 void freeFileStructs(int start, int end);
-struct dirstruct *allocDirStruct();
-struct dirstruct *allocFileStruct();
+struct dirstruct *allocDirStruct(void);
+struct dirstruct *allocFileStruct(void);
 struct dirstruct *allocDirStructB(int bytes);
 struct dirstruct *allocFileStructB(int bytes);
 
