@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: edit.c
  *    This file is part of Prime.
@@ -19,6 +19,7 @@
  *    along with Prime.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
+#include <ncurses.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -31,12 +32,21 @@
 #include "cutcopy.h"
 #include "find.h"
 #include "dirstruct.h"
-//#include "wdialog.h"
 #include "file.h"
 
 int CONFIRM_CUT_COPY;
 int ABORT_COPY;
 
+static void copyThisFile(char *fileName, FILE *logfile);
+static void copyThisDir(char *tmp, int level, FILE *logfile);
+static void moveThisDir(char *tmp, int level, FILE *logfile);
+static void cutOne(void);
+
+
+static int one(const struct dirent *unused __attribute__((unused))) 
+{
+    return 1;
+}
 
 mode_t get_mode(__mode_t st_mode)
 {
@@ -53,7 +63,7 @@ mode_t get_mode(__mode_t st_mode)
     return mode;
 }
 
-void clearSelection() 
+void clearSelection(void)
 {
     unMarkAll(DIR_WIN );
     unMarkAll(FILE_WIN);
@@ -66,21 +76,26 @@ void clearSelection()
  * Marks all items in the active window with
  * a '*' mark.
  * ******************************************/
-void markAll() 
+void markAll(int activeWindow)
 {
     int i, j = 0;
+
     if(activeWindow == DIR_WIN) 
     {
         for(i = 0; i < totalDirs; i++) 
         {
-            if((strcmp(dirs[i]->name, ".") == 0) 	//ignore '.' and '..'
-                || (strcmp(dirs[i]->name, "..") == 0)) continue;
+            //ignore '.' and '..'
+            if((strcmp(dirs[i]->name, ".") == 0) || 
+               (strcmp(dirs[i]->name, "..") == 0))
+               continue;
+
             if(dirs[i]->star == '*') continue;
             if(dirs[i]->star == '^') { removeCutDir(i); numCut--; }
             if(dirs[i]->star == '#') { removeCopyDir(i); numCopy--; }
             dirs[i]->star = '*';
             j++;
         }
+
         refreshDirView();
     } 
     else 
@@ -94,8 +109,10 @@ void markAll()
             files[i]->star = '*';
             j++;
         }
+
         refreshFileView();
     }
+
     numStarred += j;
     refreshBottomView();
 }
@@ -107,6 +124,7 @@ void markAll()
 void unMarkAll(int activeWindow)
 {
     int i, j = 0;
+
     if(activeWindow == DIR_WIN) 
     {
         for(i = 0; i < totalDirs; i++) 
@@ -117,6 +135,7 @@ void unMarkAll(int activeWindow)
             dirs[i]->star = ' ';
             j++;
         }
+
         refreshDirView();
     } 
     else 
@@ -130,8 +149,10 @@ void unMarkAll(int activeWindow)
             files[i]->star = ' ';
             j++;
         }
+
         refreshFileView();
     }
+
     numStarred -= j;
     refreshBottomView();
 }
@@ -140,15 +161,19 @@ void unMarkAll(int activeWindow)
  * Marks one item for cut in the active 
  * window with a '^' mark.
  * ******************************************/
-void cutOne() 
+void cutOne(void)
 {
     int pos;
+
     if(activeWindow == DIR_WIN) 
     {
         pos = firstVisDir+selectedDir;
+
         //ignore . & ..
-        if((strcmp(dirs[pos]->name, ".") == 0) || (strcmp(dirs[pos]->name, "..") == 0))
+        if((strcmp(dirs[pos]->name, ".") == 0) || 
+           (strcmp(dirs[pos]->name, "..") == 0))
             return;
+
         if(dirs[pos]->star == '^') return;
         else if(dirs[pos]->star == '*') numStarred--;
         else if(dirs[pos]->star == '#') 
@@ -156,6 +181,7 @@ void cutOne()
             removeCopyDir(pos); 
             numCopy--; 
         }
+
         dirs[pos]->star = '^'; 
         saveCutDir(pos);
         numCut++;
@@ -163,6 +189,7 @@ void cutOne()
     else 
     { 
         pos = firstVisFile+selectedFile;
+
         if(files[pos]->type == '%') return;
         if(files[pos]->star == '^') return;
         else if(files[pos]->star == '*') numStarred--;
@@ -171,10 +198,12 @@ void cutOne()
             removeCopyFile(pos); 
             numCopy--;
         }
+
         files[pos]->star = '^'; 
         saveCutFile(pos);
         numCut++; 
     }
+
     refreshFileView();
     refreshDirView();
     refreshBottomView();
@@ -184,16 +213,17 @@ void cutOne()
  * Sets marked items for cut in the active 
  * window with a '^' mark.
  * ******************************************/
-void cutMarked() 
+void cutMarked(void)
 {
     if(numStarred == 0) 
-    {		//if no starred items, just mark the selected item
+    {        //if no starred items, just mark the selected item
         cutOne();
         return;
     } 
     else 
-    {		//mark the starred items by changing '*' to '^'
+    {        //mark the starred items by changing '*' to '^'
         int i;
+
         for(i = 0; i < totalDirs; i++) 
         { 
             if(dirs[i]->star == '*') 
@@ -203,6 +233,7 @@ void cutMarked()
                 saveCutDir(i);
             }
         }
+
         for(i = 0; i < totalFiles; i++) 
         { 
             if(files[i]->star == '*') 
@@ -212,6 +243,7 @@ void cutMarked()
                 saveCutFile(i);
             }
         }
+
         numStarred = 0;
         refreshFileView();
         refreshDirView();
@@ -223,15 +255,19 @@ void cutMarked()
  * Marks one item for copy in the active 
  * window with a '#' mark.
  * ******************************************/
-void copyOne() 
+void copyOne(void)
 {
     int pos;
+
     if(activeWindow == DIR_WIN) 
     {
         pos = firstVisDir+selectedDir;
+
         //ignore . & ..
-        if((strcmp(dirs[pos]->name, ".") == 0) || (strcmp(dirs[pos]->name, "..") == 0))
+        if((strcmp(dirs[pos]->name, ".") == 0) || 
+           (strcmp(dirs[pos]->name, "..") == 0))
             return;
+
         if(dirs[pos]->star == '#') return;
         else if(dirs[pos]->star == '*') numStarred--;
         else if(dirs[pos]->star == '^') 
@@ -239,6 +275,7 @@ void copyOne()
             removeCutDir(pos); 
             numCut--;
         }
+
         dirs[pos]->star = '#'; 
         saveCopyDir(pos); 
         numCopy++;
@@ -246,6 +283,7 @@ void copyOne()
     else 
     { 
         pos = firstVisFile+selectedFile;
+
         if(files[pos]->type == '%') return;
         if(files[pos]->star == '#') return;
         else if(files[pos]->star == '*') numStarred--;
@@ -254,10 +292,12 @@ void copyOne()
             removeCutFile(pos);
             numCut--;
         }
+
         files[pos]->star = '#'; 
         saveCopyFile(pos);
         numCopy++; 
     }
+
     refreshFileView();
     refreshDirView();
     refreshBottomView();
@@ -268,18 +308,19 @@ void copyOne()
  * Sets marked items for copy in the active 
  * window with a '^' mark.
  * ******************************************/
-void copyMarked() 
+void copyMarked(void)
 {
     if(numStarred == 0) 
-    {		//if no starred items, just mark the selected item
+    {        //if no starred items, just mark the selected item
         //redraw main window but don't clear the area
-        drawBox(1, 1, SCREEN_H, SCREEN_W, " Prime File Manager ", NO);
+        drawBox(1, 1, SCREEN_H, SCREEN_W, " Prime File Manager ", 0);
         copyOne();
         return;
-    } 
+    }
     else 
-    {		//mark the starred items by changing '*' to '^'
+    {        //mark the starred items by changing '*' to '^'
         int i;
+
         for(i = 0; i < totalDirs; i++)
         { 
             if(dirs[i]->star == '*') 
@@ -289,6 +330,7 @@ void copyMarked()
                 saveCopyDir(i);
             }
         }
+
         for(i = 0; i < totalFiles; i++)
         { 
             if(files[i]->star == '*') 
@@ -298,12 +340,13 @@ void copyMarked()
                 saveCopyFile(i);
             }
         }
+
         numStarred = 0;
         refreshFileView();
         refreshDirView();
         refreshBottomView();
         //redraw main window but don't clear the area
-        drawBox(1, 1, SCREEN_H, SCREEN_W, " Prime File Manager ", NO);
+        drawBox(1, 1, SCREEN_H, SCREEN_W, " Prime File Manager ", 0);
     }
 }
 
@@ -312,19 +355,20 @@ void copyMarked()
  * marked for cut/copy.. it puts them in the
  * cwd path.
  * ******************************************/
-void pasteMarked() 
+void pasteMarked(void)
 {
     if(numCut == 0 && numCopy == 0) 
     {
-        msgBoxH("Nothing marked for Cut/Copy.", OK, INFO);
+        msgBoxH("Nothing marked for Cut/Copy.", BUTTON_OK, INFO);
         return;
     }
     
     CONFIRM_CUT_COPY = 0;
     ABORT_COPY = 0;
+
     int i;
-    char *logfilename = tmpnam(NULL);
-    FILE *logfile = fopen(logfilename, "wb");
+    FILE *logfile = tmpfile();
+
     /********************************************
      * First copy files marked for copying
      * ******************************************/  
@@ -333,6 +377,7 @@ void pasteMarked()
         if(ABORT_COPY) goto finish;
         copyThisFile(copyFiles[i], logfile);
     }
+
     numCopyFiles = 0;
 
     /********************************************
@@ -342,12 +387,14 @@ void pasteMarked()
     {
         if(ABORT_COPY) goto finish;
         copyThisFile(cutFiles[i], logfile);
+
         if(remove(cutFiles[i])) 
-        {	//success returns 0, otherwise err value
+        {    //success returns 0, otherwise err value
             fprintf(logfile, "Unable to remove file: %s\n", cutFiles[i]);
             //showErrorMsgBox("Unable to remove file!. ", cutFiles[i]);
         }
     }
+
     numCutFiles = 0;
 
     /********************************************
@@ -358,6 +405,7 @@ void pasteMarked()
         if(ABORT_COPY) goto finish;
         copyThisDir(copyDirs[i], 0, logfile);
     }  
+
     numCopyDirs = 0;
   
     /********************************************
@@ -368,15 +416,16 @@ void pasteMarked()
         if(ABORT_COPY) goto finish;
         moveThisDir(cutDirs[i], 0, logfile);
     }  
+
     numCutDirs = 0;
   
     numCopy = 0;
     numCut = 0;
 
-    purgeLogFile(logfile, logfilename);
-    //free(logfilename);
+    purgeLogFile(logfile);
 
 finish:
+
     CONFIRM_CUT_COPY = 0;
     ABORT_COPY = 0;
     scanDir(cwd);
@@ -386,13 +435,15 @@ finish:
  * copies the file sent as fileName into
  * the CWD with the same fileName.
  * **************************************/
-void copyThisFile(char *fileName, FILE *logfile)
+static void copyThisFile(char *fileName, FILE *logfile)
 {
     char *str;
     FILE *inFile;
     FILE *outFile;
     char buf[4096];
     int  read_size;
+    int z;
+    struct stat statbuf;
 
     //find the last '/' in the path, add one for the start of the filename
     str = strrchr(fileName, '/');
@@ -400,37 +451,40 @@ void copyThisFile(char *fileName, FILE *logfile)
     else str = fileName;
 
     // check if the file exists
-    struct stat statbuf;
-    int z = lstat(str, &statbuf);
-    if(z != -1)
+    if(lstat(str, &statbuf) != -1)
     {
         if(!CONFIRM_CUT_COPY) 
         {
-            char *s = (char *) malloc(strlen(fileName)+34);
+            char *s = malloc(strlen(fileName)+34);
+
             if(!s)
             {
-                msgBoxH("Insufficient memory", OK, ERROR);
+                msgBoxH("Insufficient memory", BUTTON_OK, ERROR);
                 return;
             }
+
             strcpy(s, "File:\n");
             strcat(s, fileName);
             strcat(s, "\nalready exists. Overwrite?");
-            z = msgBoxH(s, YES|NO|ALL, CONFIRM);
+
+            z = msgBoxH(s, BUTTON_YES|BUTTON_NO|BUTTON_ALL, CONFIRM);
             free(s);
-            if(z == NO) return;
-            if(z == ABORT)
+
+            if(z == BUTTON_NO) return;
+            else if(z == BUTTON_ABORT)
             {
                 ABORT_COPY = 1;
                 return;
             }
-            if(z == ALL) CONFIRM_CUT_COPY = 1;
+            else if(z == BUTTON_ALL) CONFIRM_CUT_COPY = 1;
         }
     }
 
     // open the input file
     if(!(inFile = fopen(fileName, "rb"))) 
     {
-        if(logfile) fprintf(logfile, "Error opening input file: %s\n", fileName);
+        if(logfile)
+             fprintf(logfile, "Error opening input file: %s\n", fileName);
         else showErrorMsgBox("Error opening input file:\n", fileName);
         return;
     }
@@ -439,24 +493,28 @@ void copyThisFile(char *fileName, FILE *logfile)
     if(!(outFile = fopen(str, "wb")))
     {
         fclose(inFile);
+
         if(logfile)
         {
             fprintf(logfile, "Error opening output file: %s\n", fileName);
         }
         else
         {
-            char *s = (char *) malloc(strlen(fileName)+37);
+            char *s = malloc(strlen(fileName)+37);
+
             if(!s)
             {
-                msgBoxH("Insufficient memory", OK, ERROR);
+                msgBoxH("Insufficient memory", BUTTON_OK, ERROR);
                 return;
             }
+
             strcpy(s, "Error opening write file:\n");
             strcat(s, fileName);
             strcat(s, "\nAborting.");
-            msgBoxH(s, OK, ERROR); 
+            msgBoxH(s, BUTTON_OK, ERROR); 
             free(s);
         }
+
         return;
     }
     
@@ -469,24 +527,24 @@ void copyThisFile(char *fileName, FILE *logfile)
     fclose(inFile);
     fclose(outFile);
     
-    // Set the file mode
-    mode_t mode = 00;
-    z = lstat(fileName, &statbuf);
-    if(z == -1)
+    if(lstat(fileName, &statbuf) == -1)
     {
-        if(logfile) fprintf(logfile, "Error: %s: %s\n", strerror(errno), fileName);
-        else msgBoxH(strerror(errno), OK, ERROR);
+        if(logfile) 
+             fprintf(logfile, "Error: %s: %s\n", strerror(errno), fileName);
+        else msgBoxH(strerror(errno), BUTTON_OK, ERROR);
         return;
     }
-    mode = get_mode(statbuf.st_mode);
-    if(chmod(str, mode) != 0) 
+
+    // Set the file mode
+    if(chmod(str, get_mode(statbuf.st_mode)) != 0) 
     {
-        if(logfile) fprintf(logfile, "Error: %s: %s\n", strerror(errno), fileName);
-        else msgBoxH(strerror(errno), OK, ERROR);
+        if(logfile) 
+             fprintf(logfile, "Error: %s: %s\n", strerror(errno), fileName);
+        else msgBoxH(strerror(errno), BUTTON_OK, ERROR);
     }
 }
 
-void __copyMoveDir(char *tmp, int level, int moving, FILE *logfile)
+static void __copyMoveDir(char *tmp, int level, int moving, FILE *logfile)
 {
     char *str;
     int n;
@@ -504,14 +562,16 @@ void __copyMoveDir(char *tmp, int level, int moving, FILE *logfile)
     else str = tmp;
   
     //show progress to the user
-    drawBox(h-2, w-30, h+2, w+30, msg, YES);
-    fprintf(stdout, "\e[%d;%dH", h-1, w-29);
-    if(strlen(str) > w-2)
+    drawBox(h-2, w-30, h+2, w+30, msg, 1);
+    move(h-2, w-30);
+
+    if((int)strlen(str) > w-2)
     {
-        for(n = 0; n < w-2; n++) putchar(str[n]);
+        for(n = 0; n < w-2; n++) addch(str[n]);
     }
-    else fprintf(stdout, "%s", str);
-    fflush(stdout);
+    else printw("%s", str);
+
+    refresh();
   
     //check if it doesn't exist, create it
     if(stat(str, &st) == -1)
@@ -522,52 +582,64 @@ void __copyMoveDir(char *tmp, int level, int moving, FILE *logfile)
     else 
     {
         oldmode = st.st_mode;
+
         if(!CONFIRM_CUT_COPY) 
         {
-            char *s = (char *) malloc(strlen(str)+39);
+            char *s = malloc(strlen(str)+39);
+
             if(!s)
             {
-                msgBoxH("Insufficient memory", OK, ERROR);
+                msgBoxH("Insufficient memory", BUTTON_OK, ERROR);
                 return;
             }
+
             strcpy(s, "Directory:\n");
             strcat(s, str);
             strcat(s, "\nalready exists. Overwrite?");
-            n = msgBoxH(s, YES|NO|ALL, CONFIRM);
+
+            n = msgBoxH(s, BUTTON_YES|BUTTON_NO|BUTTON_ALL, CONFIRM);
             free(s);
-            if(n == NO) return;
-            if(n == ABORT) { ABORT_COPY = 1; return; }
-            if(n == ALL) CONFIRM_CUT_COPY = 1;
+
+            if(n == BUTTON_NO) return;
+            else if(n == BUTTON_ABORT) { ABORT_COPY = 1; return; }
+            else if(n == BUTTON_ALL) CONFIRM_CUT_COPY = 1;
         }
     }
   
-    int z = chdir(str);
-    if(z == -1)
+    if(chdir(str) == -1)
     {
-        if(logfile) fprintf(logfile, "Error changing directory: %s\n", strerror(errno));
+        if(logfile)
+             fprintf(logfile, "Error changing directory: %s\n", strerror(errno));
         else showErrorMsgBox("Error changing directory: ", strerror(errno));
         return;
     }
   
     n = scandir(tmp, &eps, one, alphasort);
+
     if(n >= 0) 
     {
         int cnt;
+
         for(cnt = 0; cnt < n; ++cnt) 
         {
             char *d = eps[cnt]->d_name;
-            if(strcmp(d, ".") == 0 || strcmp(d, "..") == 0)	//ignore "." & ".."
-                continue;
-            char *cc = (char *) malloc(tmplen+strlen(d)+2);
+
+            //ignore "." & ".."
+            if(strcmp(d, ".") == 0 || strcmp(d, "..") == 0) continue;
+
+            char *cc = malloc(tmplen+strlen(d)+2);
+
             if(!cc)
             {
-                msgBoxH("Insufficient memory", OK, ERROR);
+                msgBoxH("Insufficient memory", BUTTON_OK, ERROR);
                 return;
             }
+
             strcpy(cc, tmp);
             strcat(cc, "/");
             strcat(cc, d);
             lstat(cc, &st);
+
             if(S_ISDIR(st.st_mode)) 
             {
                 if(moving) moveThisDir(cc, level+1, logfile);
@@ -578,28 +650,33 @@ void __copyMoveDir(char *tmp, int level, int moving, FILE *logfile)
                 copyThisFile(cc, logfile);
                 if(moving) remove(cc);
             }
+
             free(cc);
             //free(eps[cnt]->d_name);
             free(eps[cnt]);
         }
+
         free(eps);
     }
   
-    z = chdir("..");
-    if(z == -1)
+    if(chdir("..") == -1)
     {
-        if(logfile) fprintf(logfile, "Error changing directory: %s\n", strerror(errno));
+        if(logfile)
+             fprintf(logfile, "Error changing directory: %s\n", strerror(errno));
         else showErrorMsgBox("Error changing directory:\n", strerror(errno));
         return;
     }
+
     // Set the Directory mode
-    mode_t mode = oldmode;
-    if(chmod(str, mode) != 0) 
+    if(chmod(str, oldmode) != 0) 
     {
         if(logfile)
-            fprintf(logfile, "Error changing directory mode for %s: %s\n", str, strerror(errno));
-        else showErrorMsgBox("Error changing directory mode:\n", strerror(errno));
+            fprintf(logfile, "Error changing directory mode for %s: %s\n", 
+                             str, strerror(errno));
+        else showErrorMsgBox("Error changing directory mode:\n", 
+                             strerror(errno));
     }
+
     if(moving) rmdir(tmp);
 }
 
@@ -607,7 +684,7 @@ void __copyMoveDir(char *tmp, int level, int moving, FILE *logfile)
  * copies the dir sent as tmp[] recursively
  * making new subdirs in the CWD if necessary.
  * ********************************************/
-void copyThisDir(char *tmp, int level, FILE *logfile)
+static void copyThisDir(char *tmp, int level, FILE *logfile)
 {
     __copyMoveDir(tmp, level, 0, logfile);
 }
@@ -616,7 +693,7 @@ void copyThisDir(char *tmp, int level, FILE *logfile)
  * moves the dir sent as tmp[] recursively
  * making new subdirs in the CWD if necessary.
  * ********************************************/
-void moveThisDir(char tmp[], int level, FILE *logfile) 
+static void moveThisDir(char *tmp, int level, FILE *logfile) 
 {
     __copyMoveDir(tmp, level, 1, logfile);
 }
@@ -642,33 +719,38 @@ void deleteThisDir(char *tmp, int level, FILE *logfile)
     struct stat statbuf;
 
     //show progress to the user
-    drawBox(h-2, w-30, h+2, w+30, " Deleting ", YES);
-    fprintf(stdout, "\e[%d;%dH", h-1, w-29);
-    if(strlen(tmp) > w-2)
+    drawBox(h-2, w-30, h+2, w+30, " Deleting ", 1);
+    move(h-2, w-30);
+
+    if((int)strlen(tmp) > w-2)
     {
-        for(n = 0; n < w-2; n++) putchar(tmp[n]);
+        for(n = 0; n < w-2; n++) addch(tmp[n]);
     }
-    else fprintf(stdout, "%s", tmp);
-    fflush(stdout);
+    else printw("%s", tmp);
+
+    refresh();
 
     n = scandir(tmp, &eps, one, alphasort);
+
     if(n >= 0) 
     {
-        //char t[20];
-        //sprintf(t, "%d", n);
-        //msgBox(t, OK, INFO);
         if(chdir(tmp) == -1)
         {
             chdirError(tmp);
             return;
         }
+
         int cnt;
+
         for(cnt = 0; cnt < n; ++cnt) 
         {
             char *d = eps[cnt]->d_name;
-            if(strcmp(d, ".") == 0 || strcmp(d, "..") == 0)	//ignore "." & ".."
-                continue;
+
+            //ignore "." & ".."
+            if(strcmp(d, ".") == 0 || strcmp(d, "..") == 0) continue;
+
             lstat(d, &statbuf);
+
             if(S_ISDIR(statbuf.st_mode)) 
             {
                 deleteThisDir(d, level+1, logfile);
@@ -677,9 +759,12 @@ void deleteThisDir(char *tmp, int level, FILE *logfile)
             {
                 remove(d);
             }
+
             free(eps[cnt]);
         }
+
         free(eps);
+
         if(chdir("..") == -1)
         {
             chdirError("..");
@@ -698,7 +783,8 @@ void deleteThisDir(char *tmp, int level, FILE *logfile)
   
     if(rmdir(tmp) == -1)
     {
-        if(logfile) fprintf(logfile, "Error removing directory (%s): %s\n", tmp, strerror(errno));
+        if(logfile) fprintf(logfile, "Error removing directory (%s): %s\n", 
+                                     tmp, strerror(errno));
         else showErrorMsgBox("Error removing directory:\n", strerror(errno));
     }
 }
@@ -711,37 +797,62 @@ void deleteThisDir(char *tmp, int level, FILE *logfile)
 /********************************************
  * Removes marked items in the active window.
  * ******************************************/
-void deleteMarked(FILE *logfile)
+void deleteMarked(void)
 {
     int i;
-    i = msgBoxH("Delete all selected files/dirs?", YES|NO, CONFIRM);
-    if(i == NO) return;
+    char *tmp;
+
+    if(msgBoxH("Delete all selected files/dirs?", 
+            BUTTON_YES|BUTTON_NO, CONFIRM) == BUTTON_NO)
+        return;
+
     for(i = 0; i < totalFiles; i++) 
     {
         if(files[i]->star == '*')
         {
-            remove(files[i]->name);
+            // if the name is widechar, convert to a C-string
+            if(files[i]->iswcs)
+            {
+                if((tmp = to_cstring(files[i]->name, NULL)))
+                {
+                    remove(tmp);
+                    free(tmp);
+                }
+            }
+            else remove(files[i]->name);
         }
     }
+
     for(i = 0; i < totalDirs; i++) 
     {
         if(dirs[i]->star == '*') 
         {
-            deleteThisDir(dirs[i]->name, 0, logfile);
+            // if the name is widechar, convert to a C-string
+            if(dirs[i]->iswcs)
+            {
+                if((tmp = to_cstring(dirs[i]->name, NULL)))
+                {
+                    deleteThisDir(tmp, 0, NULL);
+                    free(tmp);
+                }
+            }
+            else deleteThisDir(dirs[i]->name, 0, NULL);
         }
     }
+
     numStarred = 0;
 }
 
-void editMenu_Find()
+void editMenu_Find(void)
 {
     findFile();
     hideCursor();
     scanDir(cwd);
 }
 
-void editMenu_Properties()
+void editMenu_Properties(void)
 {
     showPropertiesDialog();
     scanDir(cwd); 
 }
+
