@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: edit.h
  *    This file contains function prototypes and variable declarations
@@ -23,23 +23,16 @@
 #define __EDIT_H
 
 //functions of edit//
-void cutOne();
-void cutMarked();
-void copyMarked();
-void pasteMarked();
-void deleteMarked();
-void markAll();
+void cutMarked(void);
+void copyMarked(void);
+void pasteMarked(void);
+void deleteMarked(void);
+void markAll(int activeWindow);
 void unMarkAll(int activeWindow);
-void clearSelection();
-
-//These functions are NOT called directly, instead they are called
-//by the pasteMarked() function.
-void copyThisFile(char *fileName, FILE *logfile);
-void copyThisDir(char *tmp, int level, FILE *logfile);
-void moveThisDir(char *tmp, int level, FILE *logfile);
+void clearSelection(void);
 void deleteThisDir(char *tmp, int level, FILE *logfile);
 
-void editMenu_Find();
-void editMenu_Properties();
+void editMenu_Find(void);
+void editMenu_Properties(void);
 
 #endif
