@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: file.h
  *
@@ -26,6 +26,12 @@ void fileMenu_ExportTree();
 void fileMenu_Print();
 void fileMenu_Exit();
 char *file_open_location();
-void purgeLogFile(FILE *logfile, char *logfilename);
+void purgeLogFile(FILE *logfile);
+
+//function called by exportTree() function
+void scanThisDir(char *tmp, FILE *out, int level, int showProgress);
+
+void exportTree(void); 
+void exportTreeFromCommandLine(char *d, char *f);
 
 #endif
