@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: find.h
  *    This file contains function prototypes and variable declarations
@@ -28,30 +28,12 @@
 #include <dirent.h>
 #include <sys/stat.h>
 
-#define MAX_INPUT1_LEN  43//max length of the searched file name
-#define MAX_INPUT2_LEN  23//max length of the path to search in
+//max length of the searched file name
+#define MAX_INPUT1_LEN  43
 
-#ifdef FIND
-#   define FIND_EXTERN
-#else
-#   define FIND_EXTERN  extern
-#endif
+//max length of the path to search in
+#define MAX_INPUT2_LEN  23
 
-FIND_EXTERN int input1_len;//length of the searched file name
-FIND_EXTERN int input2_len;//length of the path to search in
-FIND_EXTERN int highlight1;	//highlighted char in input field 1
-FIND_EXTERN int highlight2;	//highlighted char in input field 2
-FIND_EXTERN char findFileName[MAX_INPUT1_LEN];	//filename to be searched for
-FIND_EXTERN char findInDir[MAX_INPUT2_LEN];	//optional for user--path to search in
-FIND_EXTERN char *startStr;
-FIND_EXTERN char *middleStr;
-FIND_EXTERN char *endStr;
-
-void findFile();
-//function called by findFile() function
-void scanDirForFile(char *tmp, int level);
-void showSearchResults();
-
-int compareFileName(char *name);
+void findFile(void);
 
 #endif
