@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: help.h
  *
@@ -20,9 +20,9 @@
 #ifndef __HELP_H
 #define __HELP_H
 
-void showReadMe();
-void showKeybindings();
-void showQuickReference();
-void showAboutBox();
+void showReadMe(void);
+void showKeybindings(void);
+void showQuickReference(void);
+void showAboutBox(void);
 
 #endif
