@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: menu.c
  *    This file is part of Prime.
@@ -19,6 +19,7 @@
  *    along with Prime.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
+#include <ncurses.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -31,15 +32,12 @@
 #include "file.h"
 #include "help.h"
 
-#define EOL	10
-
 struct menustruct
 {
     int  box[4];
     char **menuItems;
     int  menuItemCount;
     void (**func)();
-    //void (*func2)(char *arg);
 };
 
 int mSelect;
@@ -47,14 +45,22 @@ int endme;
 int menuIndex;
 struct menustruct *curMenu;
 
+char *menu[4];
+char *fileMenu[6];
+char *editMenu[8];
+char *optionsMenu[3];
+char *helpMenu[5];
+
 void (*fileFuncs[])() =
 {
-    fileMenu_CreateDir, fileMenu_Open, fileMenu_ExportTree, fileMenu_Print, fileMenu_Exit
+    fileMenu_CreateDir, fileMenu_Open, fileMenu_ExportTree, 
+    fileMenu_Print, fileMenu_Exit
 };
 
 void (*editFuncs[])() =
 {
-    cutMarked, copyMarked, pasteMarked, markAll, unMarkAll, clearSelection, editMenu_Find,
+    cutMarked, copyMarked, pasteMarked, markAll, unMarkAll, 
+    clearSelection, editMenu_Find,
     editMenu_Properties
 };
 
@@ -87,68 +93,67 @@ struct menustruct mainMenu[] =
         { 3, 23, 8, 39 }, helpMenu, hTotal, helpFuncs,
     },
 };
-    
-void drawMenuBox(struct menustruct *curMenu)
+
+static void drawMenuBox(struct menustruct *curMenu)
 {
+    int i;
     int x1 = curMenu->box[0];
     int y1 = curMenu->box[1];
     int x2 = curMenu->box[2];
     int y2 = curMenu->box[3];
     char **menuItems = curMenu->menuItems;
     int menuItemCount = curMenu->menuItemCount;
+
     setScreenColorsI(COLOR_WINDOW);
-    drawBox(x1++, y1++, x2, y2, NULL, YES);
+    drawBox(x1++, y1++, x2, y2, NULL, 1);
     setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
-    fprintf(stdout, "\e[%d;%dH%s", x1, y1, menuItems[0]);
+    mvprintw(x1-1, y1-1, "%s", menuItems[0]);
     setScreenColorsI(COLOR_WINDOW);
-    int i;
+
     for(i = 1; i < menuItemCount; i++) 
     {
-      fprintf(stdout, "\e[%d;%dH%s", i+4, y1, menuItems[i]);
+        mvprintw(i+3, y1-1, "%s", menuItems[i]);
     }
-    fprintf(stdout, "\e[%d;%dH", x1, y2-1);
-    fflush(stdout);
+
+    move(x1-1, y2-2);
+    refresh();
 }
 
-void clearMenuSelection(int y, int menuIndex, char **menuItems)
+static void clearMenuSelection(int y, int menuIndex, char **menuItems)
 {
     //clear last selection
     setScreenColorsI(COLOR_WINDOW);
-    fprintf(stdout, "\e[%d;%dH%s", menuIndex+4, y, menuItems[menuIndex]);
+    mvprintw(menuIndex+3, y-1, "%s", menuItems[menuIndex]);
+    refresh();
 }
 
-void highlightSelection(int y1, int y2, int menuIndex, char **menuItems)
+static void highlightSelection(int y1, int y2, int menuIndex, char **menuItems)
 {
     setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
-    fprintf(stdout, "\e[%d;%dH%s", menuIndex+4, y1, menuItems[menuIndex]);
-    fprintf(stdout, "\e[%d;%dH", menuIndex+4, y2);
-    fflush(stdout);
+    mvprintw(menuIndex+3, y1-1, "%s", menuItems[menuIndex]);
+    move(menuIndex+3, y2-1);
+    refresh();
 }
 
-void doEsc()
-{
-    /*
-    setScreenColorsI(COLOR_WINDOW);
-    refreshWindows();
-    fflush(stdout);
-    */
-    endme = 1;
-}
-
-void doUpDown(int step)
+static void doUpDown(int step)
 {
     clearMenuSelection(curMenu->box[1]+1, mSelect, curMenu->menuItems);
     mSelect += step;
+
     if(mSelect < 0) mSelect = curMenu->menuItemCount-1;
     else if(mSelect >= curMenu->menuItemCount) mSelect = 0;
-    highlightSelection(curMenu->box[1]+1, curMenu->box[3]-1, mSelect, curMenu->menuItems);
+
+    highlightSelection(curMenu->box[1]+1, curMenu->box[3]-1, 
+                       mSelect, curMenu->menuItems);
 }
 
-void doRightLeft(int step)
+static void doRightLeft(int step)
 {
     menuIndex += step;
+
     if(menuIndex < 0) menuIndex = totalMainMenus-1;
     else if(menuIndex == totalMainMenus) menuIndex = 0;
+
     refreshWindows();
 }
 
@@ -166,13 +171,16 @@ void showMenu(int index)
     hideCursor();
     
 loop:
+
     mSelect   = 0;
     endme     = 0;
     curMenu   = &mainMenu[menuIndex];
     drawMenuBox(curMenu);
+
     while(!endme) 
     {
         ch = getKey();
+
         switch(ch)
         {
             case('f'):                      // switch to File menu
@@ -183,7 +191,7 @@ loop:
                     refreshWindows();
                     goto loop;
                 }
-                if(CTRL)
+                else if(CTRL)
                 {
                     if(GNU_DOS_LEVEL > 1)
                     {
@@ -192,6 +200,7 @@ loop:
                     }
                 }
                 break;
+
             case('e'):                      // switch to Edit menu
                 if(ALT)
                 {
@@ -201,6 +210,7 @@ loop:
                     goto loop;
                 }
                 break;
+
             case('o'):                      // switch to Options menu
                 if(ALT)
                 {
@@ -210,6 +220,7 @@ loop:
                     goto loop;
                 }
                 break;
+
             case('h'):                      // switch to Help menu
                 if(ALT)
                 {
@@ -219,49 +230,59 @@ loop:
                     goto loop;
                 }
                 break;
+
             case('g'):
                 if(GNU_DOS_LEVEL < 3) break;
                 if(!CTRL) break;
-                doEsc();
+                endme = 1;
                 break;
+
             case(ESC_KEY):
                 if(GNU_DOS_LEVEL > 2) break;
-                doEsc();
+                endme = 1;
                 break;
+
             case('p'):
                 if(GNU_DOS_LEVEL < 2) break;
                 if(!CTRL) break;
                 doUpDown(-1);
                 break;
+
             case(UP_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doUpDown(-1);
                 break;
+
             case('n'):
                 if(GNU_DOS_LEVEL < 2) break;
                 if(!CTRL) break;
                 doUpDown(1);
                 break;
+
             case(DOWN_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doUpDown(1);
                 break;
+
             case(RIGHT_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doRightLeft(1);
                 goto loop;
                 break;
+
             case('b'):
                 if(GNU_DOS_LEVEL < 2) break;
                 if(!CTRL) break;
                 doRightLeft(-1);
                 goto loop;
                 break;
+
             case(LEFT_KEY):
                 if(GNU_DOS_LEVEL > 1) break;
                 doRightLeft(-1);
                 goto loop;
                 break;
+
             case(ENTER_KEY):
                 showCursor();
                 curMenu->func[mSelect]();
@@ -273,5 +294,6 @@ loop:
     setScreenColorsI(COLOR_WINDOW);
     refreshWindows();
     hideCursor();
-    fflush(stdout);
+    refresh();
 }
+
