@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018, 2024 (c)
  * 
  *    file: options.h
  *    This file is part of Prime.
@@ -21,22 +21,10 @@
 #ifndef __OPTIONS_H
 #define __OPTIONS_H
 
-void optionsMenu_Change_Colors();
-void optionsMenu_Reset_Config();
-void optionsMenu_Properties();
+void optionsMenu_Change_Colors(void);
+void optionsMenu_Reset_Config(void);
+void optionsMenu_Properties(void);
 
-#define changeColorsDialogOptionsN	6
-
-//array to save foreground and background colors
-int FG_COLOR[changeColorsDialogOptionsN];
-int BG_COLOR[changeColorsDialogOptionsN];
-char *COLOR_STR[8];
-int FG_COLOR_ARRAY[8];
-int BG_COLOR_ARRAY[8];
-char *findColorName(int c);
-void refreshChangeColorsDialog();
 void write_config_file();
-void saveOldColors();
-void resetColors();
-int showColorChooserDialog();
+
 #endif
